@@ -26,6 +26,7 @@ import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
+import static org.junit.Assume.assumeTrue;
 
 import java.io.IOException;
 import java.net.Socket;
@@ -39,22 +40,29 @@ import javax.net.ssl.SSLPeerUnverifiedException;
 import javax.net.ssl.SSLSession;
 import javax.net.ssl.SSLSocket;
 
+import org.apache.qpid.jms.JmsConnectionExtensions;
 import org.apache.qpid.jms.JmsConnectionFactory;
 import org.apache.qpid.jms.test.QpidJmsTestCase;
 import org.apache.qpid.jms.test.testpeer.TestAmqpPeer;
-import org.apache.qpid.jms.transports.TransportSslOptions;
+import org.apache.qpid.jms.transports.TransportOptions;
 import org.apache.qpid.jms.transports.TransportSupport;
+import org.apache.qpid.jms.transports.netty.NettySimpleAmqpServer;
 import org.junit.Test;
 
+import io.netty.handler.ssl.OpenSsl;
+
 public class SslIntegrationTest extends QpidJmsTestCase {
 
-    private static final String BROKER_JKS_KEYSTORE = "src/test/resources/broker-jks.keystore";
-    private static final String BROKER_JKS_TRUSTSTORE = "src/test/resources/broker-jks.truststore";
+    private static final String BROKER_PKCS12_KEYSTORE = "src/test/resources/broker-pkcs12.keystore";
+    private static final String BROKER_PKCS12_TRUSTSTORE = "src/test/resources/broker-pkcs12.truststore";
     private static final String CLIENT_MULTI_KEYSTORE = "src/test/resources/client-multiple-keys-jks.keystore";
     private static final String CLIENT_JKS_TRUSTSTORE = "src/test/resources/client-jks.truststore";
+    private static final String CLIENT_PKCS12_TRUSTSTORE = "src/test/resources/client-pkcs12.truststore";
     private static final String OTHER_CA_TRUSTSTORE = "src/test/resources/other-ca-jks.truststore";
     private static final String CLIENT_JKS_KEYSTORE = "src/test/resources/client-jks.keystore";
+    private static final String CLIENT_PKCS12_KEYSTORE = "src/test/resources/client-pkcs12.keystore";
     private static final String CLIENT2_JKS_KEYSTORE = "src/test/resources/client2-jks.keystore";
+    private static final String CUSTOM_STORE_TYPE_PKCS12 = "pkcs12";
     private static final String PASSWORD = "password";
     private static final String WRONG_PASSWORD = "wrong-password";
 
@@ -67,24 +75,39 @@ public class SslIntegrationTest extends QpidJmsTestCase {
     private static final String ALIAS_CA_CERT = "ca";
 
     private static final String JAVAX_NET_SSL_KEY_STORE = "javax.net.ssl.keyStore";
+    private static final String JAVAX_NET_SSL_KEY_STORE_TYPE = "javax.net.ssl.keyStoreType";
     private static final String JAVAX_NET_SSL_KEY_STORE_PASSWORD = "javax.net.ssl.keyStorePassword";
     private static final String JAVAX_NET_SSL_TRUST_STORE = "javax.net.ssl.trustStore";
+    private static final String JAVAX_NET_SSL_TRUST_STORE_TYPE = "javax.net.ssl.trustStoreType";
     private static final String JAVAX_NET_SSL_TRUST_STORE_PASSWORD = "javax.net.ssl.trustStorePassword";
 
     private final IntegrationTestFixture testFixture = new IntegrationTestFixture();
 
     @Test(timeout = 20000)
-    public void testCreateAndCloseSslConnection() throws Exception {
-        TransportSslOptions sslOptions = new TransportSslOptions();
-        sslOptions.setKeyStoreLocation(BROKER_JKS_KEYSTORE);
+    public void testCreateAndCloseSslConnectionJDK() throws Exception {
+        testCreateAndCloseSslConnection(false);
+    }
+
+    @Test(timeout = 20000)
+    public void testCreateAndCloseSslConnectionOpenSSL() throws Exception {
+        assumeTrue(OpenSsl.isAvailable());
+        assumeTrue(OpenSsl.supportsKeyManagerFactory());
+
+        testCreateAndCloseSslConnection(true);
+    }
+
+    private void testCreateAndCloseSslConnection(boolean openSSL) throws Exception {
+        TransportOptions sslOptions = new TransportOptions();
+        sslOptions.setKeyStoreLocation(BROKER_PKCS12_KEYSTORE);
         sslOptions.setKeyStorePassword(PASSWORD);
         sslOptions.setVerifyHost(false);
 
-        SSLContext context = TransportSupport.createSslContext(sslOptions);
+        SSLContext context = TransportSupport.createJdkSslContext(sslOptions);
 
         try (TestAmqpPeer testPeer = new TestAmqpPeer(context, false);) {
             String connOptions = "?transport.trustStoreLocation=" + CLIENT_JKS_TRUSTSTORE + "&" +
-                                 "transport.trustStorePassword=" + PASSWORD;
+                                 "transport.trustStorePassword=" + PASSWORD + "&" +
+                                 "transport.useOpenSSL=" + openSSL;
             Connection connection = testFixture.establishConnecton(testPeer, true, connOptions, null, null, true);
 
             Socket socket = testPeer.getClientSocket();
@@ -96,13 +119,25 @@ public class SslIntegrationTest extends QpidJmsTestCase {
     }
 
     @Test(timeout = 20000)
-    public void testCreateSslConnectionWithServerSendingPreemptiveData() throws Exception {
-        TransportSslOptions serverSslOptions = new TransportSslOptions();
-        serverSslOptions.setKeyStoreLocation(BROKER_JKS_KEYSTORE);
+    public void testCreateSslConnectionWithServerSendingPreemptiveDataJDK() throws Exception {
+        doTestCreateSslConnectionWithServerSendingPreemptiveData(false);
+    }
+
+    @Test(timeout = 20000)
+    public void testCreateSslConnectionWithServerSendingPreemptiveDataOpenSSL() throws Exception {
+        assumeTrue(OpenSsl.isAvailable());
+        assumeTrue(OpenSsl.supportsKeyManagerFactory());
+
+        doTestCreateSslConnectionWithServerSendingPreemptiveData(true);
+    }
+
+    private void doTestCreateSslConnectionWithServerSendingPreemptiveData(boolean openSSL) throws Exception {
+        TransportOptions serverSslOptions = new TransportOptions();
+        serverSslOptions.setKeyStoreLocation(BROKER_PKCS12_KEYSTORE);
         serverSslOptions.setKeyStorePassword(PASSWORD);
         serverSslOptions.setVerifyHost(false);
 
-        SSLContext serverSslContext = TransportSupport.createSslContext(serverSslOptions);
+        SSLContext serverSslContext = TransportSupport.createJdkSslContext(serverSslOptions);
 
         boolean sendServerSaslHeaderPreEmptively = true;
         try (TestAmqpPeer testPeer = new TestAmqpPeer(serverSslContext, false, sendServerSaslHeaderPreEmptively);) {
@@ -112,7 +147,8 @@ public class SslIntegrationTest extends QpidJmsTestCase {
             testPeer.expectBegin();
 
             String connOptions = "?transport.trustStoreLocation=" + CLIENT_JKS_TRUSTSTORE + "&" +
-                                  "transport.trustStorePassword=" + PASSWORD;
+                                  "transport.trustStorePassword=" + PASSWORD + "&" +
+                                  "transport.useOpenSSL=" + openSSL;
 
             JmsConnectionFactory factory = new JmsConnectionFactory("amqps://localhost:" + testPeer.getServerPort() + connOptions);
             Connection connection = factory.createConnection();
@@ -127,21 +163,34 @@ public class SslIntegrationTest extends QpidJmsTestCase {
     }
 
     @Test(timeout = 20000)
-    public void testCreateAndCloseSslConnectionWithClientAuth() throws Exception {
-        TransportSslOptions sslOptions = new TransportSslOptions();
-        sslOptions.setKeyStoreLocation(BROKER_JKS_KEYSTORE);
-        sslOptions.setTrustStoreLocation(BROKER_JKS_TRUSTSTORE);
+    public void testCreateAndCloseSslConnectionWithClientAuthJDK() throws Exception {
+        doTestCreateAndCloseSslConnectionWithClientAuth(false);
+    }
+
+    @Test(timeout = 20000)
+    public void testCreateAndCloseSslConnectionWithClientAuthOpenSSL() throws Exception {
+        assumeTrue(OpenSsl.isAvailable());
+        assumeTrue(OpenSsl.supportsKeyManagerFactory());
+
+        doTestCreateAndCloseSslConnectionWithClientAuth(true);
+    }
+
+    private void doTestCreateAndCloseSslConnectionWithClientAuth(boolean openSSL) throws Exception {
+        TransportOptions sslOptions = new TransportOptions();
+        sslOptions.setKeyStoreLocation(BROKER_PKCS12_KEYSTORE);
+        sslOptions.setTrustStoreLocation(BROKER_PKCS12_TRUSTSTORE);
         sslOptions.setKeyStorePassword(PASSWORD);
         sslOptions.setTrustStorePassword(PASSWORD);
         sslOptions.setVerifyHost(false);
 
-        SSLContext context = TransportSupport.createSslContext(sslOptions);
+        SSLContext context = TransportSupport.createJdkSslContext(sslOptions);
 
         try (TestAmqpPeer testPeer = new TestAmqpPeer(context, true);) {
             String connOptions = "?transport.keyStoreLocation=" + CLIENT_MULTI_KEYSTORE + "&" +
                                  "transport.keyStorePassword=" + PASSWORD + "&" +
                                  "transport.trustStoreLocation=" + CLIENT_JKS_TRUSTSTORE + "&" +
-                                 "transport.trustStorePassword=" + PASSWORD;
+                                 "transport.trustStorePassword=" + PASSWORD + "&" +
+                                 "transport.useOpenSSL=" + openSSL;
             Connection connection = testFixture.establishConnecton(testPeer, true, connOptions, null, null, true);
 
             Socket socket = testPeer.getClientSocket();
@@ -154,27 +203,38 @@ public class SslIntegrationTest extends QpidJmsTestCase {
     }
 
     @Test(timeout = 20000)
-    public void testCreateAndCloseSslConnectionWithAlias() throws Exception {
-        doConnectionWithAliasTestImpl(CLIENT_KEY_ALIAS, CLIENT_DN);
-        doConnectionWithAliasTestImpl(CLIENT2_KEY_ALIAS, CLIENT2_DN);
+    public void testCreateAndCloseSslConnectionWithAliasJDK() throws Exception {
+        doConnectionWithAliasTestImpl(CLIENT_KEY_ALIAS, CLIENT_DN, false);
+        doConnectionWithAliasTestImpl(CLIENT2_KEY_ALIAS, CLIENT2_DN, false);
     }
 
-    private void doConnectionWithAliasTestImpl(String alias, String expectedDN) throws Exception, JMSException, SSLPeerUnverifiedException, IOException {
-        TransportSslOptions sslOptions = new TransportSslOptions();
-        sslOptions.setKeyStoreLocation(BROKER_JKS_KEYSTORE);
-        sslOptions.setTrustStoreLocation(BROKER_JKS_TRUSTSTORE);
+    @Test(timeout = 20000)
+    public void testCreateAndCloseSslConnectionWithAliasOpenSSL() throws Exception {
+        assumeTrue(OpenSsl.isAvailable());
+        assumeTrue(OpenSsl.supportsKeyManagerFactory());
+
+        doConnectionWithAliasTestImpl(CLIENT_KEY_ALIAS, CLIENT_DN, true);
+        doConnectionWithAliasTestImpl(CLIENT2_KEY_ALIAS, CLIENT2_DN, true);
+    }
+
+    private void doConnectionWithAliasTestImpl(String alias, String expectedDN, boolean requestOpenSSL) throws Exception, JMSException, SSLPeerUnverifiedException, IOException {
+        TransportOptions sslOptions = new TransportOptions();
+        sslOptions.setKeyStoreLocation(BROKER_PKCS12_KEYSTORE);
+        sslOptions.setTrustStoreLocation(BROKER_PKCS12_TRUSTSTORE);
         sslOptions.setKeyStorePassword(PASSWORD);
         sslOptions.setTrustStorePassword(PASSWORD);
         sslOptions.setVerifyHost(false);
 
-        SSLContext context = TransportSupport.createSslContext(sslOptions);
+        SSLContext context = TransportSupport.createJdkSslContext(sslOptions);
 
         try (TestAmqpPeer testPeer = new TestAmqpPeer(context, true);) {
             String connOptions = "?transport.keyStoreLocation=" + CLIENT_MULTI_KEYSTORE + "&" +
                                  "transport.keyStorePassword=" + PASSWORD + "&" +
                                  "transport.trustStoreLocation=" + CLIENT_JKS_TRUSTSTORE + "&" +
                                  "transport.trustStorePassword=" + PASSWORD + "&" +
-                                 "transport.keyAlias=" + alias;
+                                 "transport.keyAlias=" + alias + "&" +
+                                 "transport.useOpenSSL=" + requestOpenSSL;
+
             Connection connection = testFixture.establishConnecton(testPeer, true, connOptions, null, null, true);
 
             Socket socket = testPeer.getClientSocket();
@@ -205,14 +265,14 @@ public class SslIntegrationTest extends QpidJmsTestCase {
     }
 
     private void doCreateConnectionWithInvalidAliasTestImpl(String alias) throws Exception, IOException {
-        TransportSslOptions sslOptions = new TransportSslOptions();
-        sslOptions.setKeyStoreLocation(BROKER_JKS_KEYSTORE);
-        sslOptions.setTrustStoreLocation(BROKER_JKS_TRUSTSTORE);
+        TransportOptions sslOptions = new TransportOptions();
+        sslOptions.setKeyStoreLocation(BROKER_PKCS12_KEYSTORE);
+        sslOptions.setTrustStoreLocation(BROKER_PKCS12_TRUSTSTORE);
         sslOptions.setKeyStorePassword(PASSWORD);
         sslOptions.setTrustStorePassword(PASSWORD);
         sslOptions.setVerifyHost(false);
 
-        SSLContext context = TransportSupport.createSslContext(sslOptions);
+        SSLContext context = TransportSupport.createJdkSslContext(sslOptions);
 
         try (TestAmqpPeer testPeer = new TestAmqpPeer(context, true);) {
             String connOptions = "?transport.keyStoreLocation=" + CLIENT_MULTI_KEYSTORE + "&" +
@@ -247,32 +307,52 @@ public class SslIntegrationTest extends QpidJmsTestCase {
         assertNotEquals(CLIENT_DN, CLIENT2_DN);
 
         // Connect providing the Client 1 details via context override, expect Client1 DN.
-        doConnectionWithSslContextOverride(CLIENT_JKS_KEYSTORE, CLIENT_DN);
+        doConnectionWithSslContextOverride(CLIENT_JKS_KEYSTORE, CLIENT_DN, false);
         // Connect providing the Client 2 details via context override, expect Client2 DN instead.
-        doConnectionWithSslContextOverride(CLIENT2_JKS_KEYSTORE, CLIENT2_DN);
+        doConnectionWithSslContextOverride(CLIENT2_JKS_KEYSTORE, CLIENT2_DN, false);
     }
 
-    private void doConnectionWithSslContextOverride(String clientKeyStorePath, String expectedDN) throws Exception {
-        TransportSslOptions serverSslOptions = new TransportSslOptions();
-        serverSslOptions.setKeyStoreLocation(BROKER_JKS_KEYSTORE);
-        serverSslOptions.setTrustStoreLocation(BROKER_JKS_TRUSTSTORE);
+    @Test(timeout = 20000)
+    public void testCreateConnectionWithSslContextOverrideByExtension() throws Exception {
+        assertNotEquals(CLIENT_JKS_KEYSTORE, CLIENT2_JKS_KEYSTORE);
+        assertNotEquals(CLIENT_DN, CLIENT2_DN);
+
+        // Connect providing the Client 1 details via context override, expect Client1 DN.
+        doConnectionWithSslContextOverride(CLIENT_JKS_KEYSTORE, CLIENT_DN, true);
+        // Connect providing the Client 2 details via context override, expect Client2 DN instead.
+        doConnectionWithSslContextOverride(CLIENT2_JKS_KEYSTORE, CLIENT2_DN, true);
+    }
+
+    private void doConnectionWithSslContextOverride(String clientKeyStorePath, String expectedDN, boolean useExtension) throws Exception {
+        TransportOptions serverSslOptions = new TransportOptions();
+        serverSslOptions.setKeyStoreLocation(BROKER_PKCS12_KEYSTORE);
+        serverSslOptions.setTrustStoreLocation(BROKER_PKCS12_TRUSTSTORE);
         serverSslOptions.setKeyStorePassword(PASSWORD);
         serverSslOptions.setTrustStorePassword(PASSWORD);
         serverSslOptions.setVerifyHost(false);
 
-        SSLContext serverContext = TransportSupport.createSslContext(serverSslOptions);
+        SSLContext serverContext = TransportSupport.createJdkSslContext(serverSslOptions);
 
-        TransportSslOptions clientSslOptions = new TransportSslOptions();
+        TransportOptions clientSslOptions = new TransportOptions();
         clientSslOptions.setKeyStoreLocation(clientKeyStorePath);
         clientSslOptions.setTrustStoreLocation(CLIENT_JKS_TRUSTSTORE);
         clientSslOptions.setKeyStorePassword(PASSWORD);
         clientSslOptions.setTrustStorePassword(PASSWORD);
 
-        SSLContext clientContext = TransportSupport.createSslContext(clientSslOptions);
-
         try (TestAmqpPeer testPeer = new TestAmqpPeer(serverContext, true);) {
             JmsConnectionFactory factory = new JmsConnectionFactory("amqps://localhost:" + testPeer.getServerPort());
-            factory.setSslContext(clientContext);
+
+            if (useExtension) {
+                factory.setExtension(JmsConnectionExtensions.SSL_CONTEXT.toString(), (options, uri) -> {
+                    try {
+                        return TransportSupport.createJdkSslContext(clientSslOptions);
+                    } catch (Exception e) {
+                        throw new RuntimeException(e.getMessage(), e);
+                    }
+                });
+            } else {
+                factory.setSslContext(TransportSupport.createJdkSslContext(clientSslOptions));
+            }
 
             testPeer.expectSaslPlain("guest", "guest");
             testPeer.expectOpen();
@@ -314,27 +394,27 @@ public class SslIntegrationTest extends QpidJmsTestCase {
         // Connect without providing a context, expect Client1 DN.
         doConnectionWithSslContextOverrideAndURIConfig(null, CLIENT_DN);
 
-        TransportSslOptions clientSslOptions = new TransportSslOptions();
+        TransportOptions clientSslOptions = new TransportOptions();
         clientSslOptions.setKeyStoreLocation(CLIENT2_JKS_KEYSTORE);
         clientSslOptions.setTrustStoreLocation(CLIENT_JKS_TRUSTSTORE);
         clientSslOptions.setKeyStorePassword(PASSWORD);
         clientSslOptions.setTrustStorePassword(PASSWORD);
 
-        SSLContext clientContext = TransportSupport.createSslContext(clientSslOptions);
+        SSLContext clientContext = TransportSupport.createJdkSslContext(clientSslOptions);
 
         // Connect providing the Client 2 details via context override, expect Client2 DN instead.
         doConnectionWithSslContextOverrideAndURIConfig(clientContext, CLIENT2_DN);
     }
 
     private void doConnectionWithSslContextOverrideAndURIConfig(SSLContext clientContext, String expectedDN) throws Exception {
-        TransportSslOptions serverSslOptions = new TransportSslOptions();
-        serverSslOptions.setKeyStoreLocation(BROKER_JKS_KEYSTORE);
-        serverSslOptions.setTrustStoreLocation(BROKER_JKS_TRUSTSTORE);
+        TransportOptions serverSslOptions = new TransportOptions();
+        serverSslOptions.setKeyStoreLocation(BROKER_PKCS12_KEYSTORE);
+        serverSslOptions.setTrustStoreLocation(BROKER_PKCS12_TRUSTSTORE);
         serverSslOptions.setKeyStorePassword(PASSWORD);
         serverSslOptions.setTrustStorePassword(PASSWORD);
         serverSslOptions.setVerifyHost(false);
 
-        SSLContext serverContext = TransportSupport.createSslContext(serverSslOptions);
+        SSLContext serverContext = TransportSupport.createJdkSslContext(serverSslOptions);
 
         try (TestAmqpPeer testPeer = new TestAmqpPeer(serverContext, true);) {
             String connOptions = "?transport.keyStoreLocation=" + CLIENT_JKS_KEYSTORE + "&" +
@@ -407,6 +487,37 @@ public class SslIntegrationTest extends QpidJmsTestCase {
         doConfigureStoresWithSslSystemPropertiesTestImpl(CLIENT2_DN);
     }
 
+    @Test(timeout = 20000)
+    public void testConfigurePkcs12StoresWithSslSystemProperties() throws Exception {
+        // Set properties and expect connection as Client1
+        setSslSystemPropertiesForCurrentTest(CLIENT_PKCS12_KEYSTORE, CUSTOM_STORE_TYPE_PKCS12, PASSWORD, CLIENT_PKCS12_TRUSTSTORE, CUSTOM_STORE_TYPE_PKCS12, PASSWORD);
+        doConfigureStoresWithSslSystemPropertiesTestImpl(CLIENT_DN);
+    }
+
+    @Test(timeout = 30000)
+    public void testNonSslConnectionFailsToSslServer() throws Exception {
+        TransportOptions serverOptions = new TransportOptions();
+        serverOptions.setKeyStoreLocation(BROKER_PKCS12_KEYSTORE);
+        serverOptions.setKeyStorePassword(PASSWORD);
+        serverOptions.setVerifyHost(false);
+
+        try (NettySimpleAmqpServer server = new NettySimpleAmqpServer(serverOptions, true)) {
+            server.start();
+
+            JmsConnectionFactory factory = new JmsConnectionFactory("amqp://localhost:" + server.getServerPort() + "?jms.connectTimeout=25");
+
+            try {
+                factory.createConnection();
+                fail("should not have connected");
+            }
+            catch (JMSException jmse) {
+                String message = jmse.getMessage();
+                assertNotNull(message);
+                assertTrue("Unexpected message: " + message, message.contains("Timed out while waiting to connect"));
+            }
+        }
+    }
+
     private void setSslSystemPropertiesForCurrentTest(String keystore, String keystorePassword, String truststore, String truststorePassword) {
         setTestSystemProperty(JAVAX_NET_SSL_KEY_STORE, keystore);
         setTestSystemProperty(JAVAX_NET_SSL_KEY_STORE_PASSWORD, keystorePassword);
@@ -414,15 +525,24 @@ public class SslIntegrationTest extends QpidJmsTestCase {
         setTestSystemProperty(JAVAX_NET_SSL_TRUST_STORE_PASSWORD, truststorePassword);
     }
 
+    private void setSslSystemPropertiesForCurrentTest(String keystore, String keystoreType, String keystorePassword, String truststore, String truststoreType, String truststorePassword) {
+        setTestSystemProperty(JAVAX_NET_SSL_KEY_STORE, keystore);
+        setTestSystemProperty(JAVAX_NET_SSL_KEY_STORE_TYPE, keystoreType);
+        setTestSystemProperty(JAVAX_NET_SSL_KEY_STORE_PASSWORD, keystorePassword);
+        setTestSystemProperty(JAVAX_NET_SSL_TRUST_STORE, truststore);
+        setTestSystemProperty(JAVAX_NET_SSL_TRUST_STORE_TYPE, truststoreType);
+        setTestSystemProperty(JAVAX_NET_SSL_TRUST_STORE_PASSWORD, truststorePassword);
+    }
+
     private void doConfigureStoresWithSslSystemPropertiesTestImpl(String expectedDN) throws Exception {
-        TransportSslOptions serverSslOptions = new TransportSslOptions();
-        serverSslOptions.setKeyStoreLocation(BROKER_JKS_KEYSTORE);
-        serverSslOptions.setTrustStoreLocation(BROKER_JKS_TRUSTSTORE);
+        TransportOptions serverSslOptions = new TransportOptions();
+        serverSslOptions.setKeyStoreLocation(BROKER_PKCS12_KEYSTORE);
+        serverSslOptions.setTrustStoreLocation(BROKER_PKCS12_TRUSTSTORE);
         serverSslOptions.setKeyStorePassword(PASSWORD);
         serverSslOptions.setTrustStorePassword(PASSWORD);
         serverSslOptions.setVerifyHost(false);
 
-        SSLContext serverSslContext = TransportSupport.createSslContext(serverSslOptions);
+        SSLContext serverSslContext = TransportSupport.createJdkSslContext(serverSslOptions);
 
         try (TestAmqpPeer testPeer = new TestAmqpPeer(serverSslContext, true);) {
             Connection connection = testFixture.establishConnecton(testPeer, true, null, null, null, true);
