@@ -48,6 +48,7 @@ import org.apache.qpid.jms.JmsQueue;
 import org.apache.qpid.jms.JmsSession;
 import org.apache.qpid.jms.JmsTopic;
 import org.apache.qpid.jms.message.JmsOutboundMessageDispatch;
+import org.apache.qpid.jms.provider.ProviderException;
 import org.apache.qpid.jms.provider.mock.MockRemotePeer;
 import org.apache.qpid.jms.test.Wait;
 import org.junit.After;
@@ -448,8 +449,6 @@ public class JmsMessageProducerTest extends JmsConnectionTestSupport {
     public void testInOrderSendAcksCompletionsReturnInOrder() throws Exception {
         final int MESSAGE_COUNT = 3;
 
-        final MockRemotePeer remotePoor = MockRemotePeer.INSTANCE;
-
         JmsConnectionFactory factory = new JmsConnectionFactory(
             "mock://localhost?mock.delayCompletionCalls=true");
 
@@ -465,17 +464,17 @@ public class JmsMessageProducerTest extends JmsConnectionTestSupport {
         assertTrue("Not all sends made it to the remote", Wait.waitFor(new Wait.Condition() {
 
             @Override
-            public boolean isSatisified() throws Exception {
-                return remotePoor.getPendingCompletions(destination).size() == MESSAGE_COUNT;
+            public boolean isSatisfied() throws Exception {
+                return remotePeer.getPendingCompletions(destination).size() == MESSAGE_COUNT;
             }
         }));
 
-        remotePoor.completeAllPendingSends(destination);
+        remotePeer.completeAllPendingSends(destination);
 
         assertTrue("Not all completions triggered", Wait.waitFor(new Wait.Condition() {
 
             @Override
-            public boolean isSatisified() throws Exception {
+            public boolean isSatisfied() throws Exception {
                 return listener.getCompletedSends().size() == MESSAGE_COUNT;
             }
         }));
@@ -489,8 +488,6 @@ public class JmsMessageProducerTest extends JmsConnectionTestSupport {
     public void testReversedOrderSendAcksCompletionsReturnInOrder() throws Exception {
         final int MESSAGE_COUNT = 3;
 
-        final MockRemotePeer remotePoor = MockRemotePeer.INSTANCE;
-
         JmsConnectionFactory factory = new JmsConnectionFactory(
             "mock://localhost?mock.delayCompletionCalls=true");
 
@@ -506,24 +503,24 @@ public class JmsMessageProducerTest extends JmsConnectionTestSupport {
         assertTrue("Not all sends made it to the remote", Wait.waitFor(new Wait.Condition() {
 
             @Override
-            public boolean isSatisified() throws Exception {
-                return remotePoor.getPendingCompletions(destination).size() == MESSAGE_COUNT;
+            public boolean isSatisfied() throws Exception {
+                return remotePeer.getPendingCompletions(destination).size() == MESSAGE_COUNT;
             }
         }));
 
-        List<JmsOutboundMessageDispatch> pending = remotePoor.getPendingCompletions(destination);
+        List<JmsOutboundMessageDispatch> pending = remotePeer.getPendingCompletions(destination);
         assertEquals(MESSAGE_COUNT, pending.size());
         Collections.reverse(pending);
 
         for (JmsOutboundMessageDispatch envelope : pending) {
             LOG.info("Trigger completion of message: {}", envelope.getMessage().getJMSMessageID());
-            remotePoor.completePendingSend(envelope);
+            remotePeer.completePendingSend(envelope);
         }
 
         assertTrue("Not all completions triggered", Wait.waitFor(new Wait.Condition() {
 
             @Override
-            public boolean isSatisified() throws Exception {
+            public boolean isSatisfied() throws Exception {
                 return listener.getCompletedSends().size() == MESSAGE_COUNT;
             }
         }));
@@ -537,8 +534,6 @@ public class JmsMessageProducerTest extends JmsConnectionTestSupport {
     public void testInOrderSendFailuresCompletionsReturnInOrder() throws Exception {
         final int MESSAGE_COUNT = 3;
 
-        final MockRemotePeer remotePoor = MockRemotePeer.INSTANCE;
-
         JmsConnectionFactory factory = new JmsConnectionFactory(
             "mock://localhost?mock.delayCompletionCalls=true");
 
@@ -553,16 +548,16 @@ public class JmsMessageProducerTest extends JmsConnectionTestSupport {
         assertTrue("Not all messages sent", Wait.waitFor(new Wait.Condition() {
 
             @Override
-            public boolean isSatisified() throws Exception {
-                return remotePoor.getPendingCompletions(destination).size() == MESSAGE_COUNT;
+            public boolean isSatisfied() throws Exception {
+                return remotePeer.getPendingCompletions(destination).size() == MESSAGE_COUNT;
             }
         }));
-        remotePoor.failAllPendingSends(destination, new JMSException("Could not send message"));
+        remotePeer.failAllPendingSends(destination, new ProviderException("Could not send message"));
 
         assertTrue("Not all completions triggered", Wait.waitFor(new Wait.Condition() {
 
             @Override
-            public boolean isSatisified() throws Exception {
+            public boolean isSatisfied() throws Exception {
                 return listener.getFailedSends().size() == MESSAGE_COUNT;
             }
         }));
@@ -576,8 +571,6 @@ public class JmsMessageProducerTest extends JmsConnectionTestSupport {
     public void testReversedOrderSendAcksFailuresReturnInOrder() throws Exception {
         final int MESSAGE_COUNT = 3;
 
-        final MockRemotePeer remotePoor = MockRemotePeer.INSTANCE;
-
         JmsConnectionFactory factory = new JmsConnectionFactory(
             "mock://localhost?mock.delayCompletionCalls=true");
 
@@ -593,24 +586,24 @@ public class JmsMessageProducerTest extends JmsConnectionTestSupport {
         assertTrue("Not all sends made it to the remote", Wait.waitFor(new Wait.Condition() {
 
             @Override
-            public boolean isSatisified() throws Exception {
-                return remotePoor.getPendingCompletions(destination).size() == MESSAGE_COUNT;
+            public boolean isSatisfied() throws Exception {
+                return remotePeer.getPendingCompletions(destination).size() == MESSAGE_COUNT;
             }
         }));
 
-        List<JmsOutboundMessageDispatch> pending = remotePoor.getPendingCompletions(destination);
+        List<JmsOutboundMessageDispatch> pending = remotePeer.getPendingCompletions(destination);
         assertEquals(MESSAGE_COUNT, pending.size());
         Collections.reverse(pending);
 
         for (JmsOutboundMessageDispatch envelope : pending) {
             LOG.info("Trigger failure of message: {}", envelope.getMessage().getJMSMessageID());
-            remotePoor.failPendingSend(envelope, new JMSException("Failed to send message"));
+            remotePeer.failPendingSend(envelope, new ProviderException("Failed to send message"));
         }
 
         assertTrue("Not all failures triggered", Wait.waitFor(new Wait.Condition() {
 
             @Override
-            public boolean isSatisified() throws Exception {
+            public boolean isSatisfied() throws Exception {
                 return listener.getFailedSends().size() == MESSAGE_COUNT;
             }
         }));
@@ -624,8 +617,6 @@ public class JmsMessageProducerTest extends JmsConnectionTestSupport {
     public void testInterleavedCompletionsReturnedInOrder() throws Exception {
         final int MESSAGE_COUNT = 3;
 
-        final MockRemotePeer remotePoor = MockRemotePeer.INSTANCE;
-
         JmsConnectionFactory factory = new JmsConnectionFactory(
             "mock://localhost?mock.delayCompletionCalls=true");
 
@@ -641,12 +632,12 @@ public class JmsMessageProducerTest extends JmsConnectionTestSupport {
         assertTrue("Not all sends made it to the remote", Wait.waitFor(new Wait.Condition() {
 
             @Override
-            public boolean isSatisified() throws Exception {
-                return remotePoor.getPendingCompletions(destination).size() == MESSAGE_COUNT;
+            public boolean isSatisfied() throws Exception {
+                return remotePeer.getPendingCompletions(destination).size() == MESSAGE_COUNT;
             }
         }));
 
-        List<JmsOutboundMessageDispatch> pending = remotePoor.getPendingCompletions(destination);
+        List<JmsOutboundMessageDispatch> pending = remotePeer.getPendingCompletions(destination);
         assertEquals(MESSAGE_COUNT, pending.size());
         Collections.reverse(pending);
 
@@ -654,17 +645,17 @@ public class JmsMessageProducerTest extends JmsConnectionTestSupport {
             int sequence = envelope.getMessage().getIntProperty("sequence");
             if (sequence % 2 == 0) {
                 LOG.info("Trigger completion of message: {}", envelope.getMessage().getJMSMessageID());
-                remotePoor.completePendingSend(envelope);
+                remotePeer.completePendingSend(envelope);
             } else {
                 LOG.info("Trigger failure of message: {}", envelope.getMessage().getJMSMessageID());
-                remotePoor.failPendingSend(envelope, new JMSException("Failed to send message"));
+                remotePeer.failPendingSend(envelope, new ProviderException("Failed to send message"));
             }
         }
 
         assertTrue("Not all completions triggered", Wait.waitFor(new Wait.Condition() {
 
             @Override
-            public boolean isSatisified() throws Exception {
+            public boolean isSatisfied() throws Exception {
                 return listener.getCombinedSends().size() == MESSAGE_COUNT;
             }
         }));
@@ -678,8 +669,6 @@ public class JmsMessageProducerTest extends JmsConnectionTestSupport {
     public void testCompletionListenerOnCompleteCallsProducerCloseThrowsISE() throws Exception {
         final int MESSAGE_COUNT = 1;
 
-        final MockRemotePeer remotePoor = MockRemotePeer.INSTANCE;
-
         JmsConnectionFactory factory = new JmsConnectionFactory(
             "mock://localhost?mock.delayCompletionCalls=true");
 
@@ -713,12 +702,12 @@ public class JmsMessageProducerTest extends JmsConnectionTestSupport {
         assertTrue("Not all sends made it to the remote", Wait.waitFor(new Wait.Condition() {
 
             @Override
-            public boolean isSatisified() throws Exception {
-                return remotePoor.getPendingCompletions(destination).size() == MESSAGE_COUNT;
+            public boolean isSatisfied() throws Exception {
+                return remotePeer.getPendingCompletions(destination).size() == MESSAGE_COUNT;
             }
         }));
 
-        remotePoor.completeAllPendingSends(destination);
+        remotePeer.completeAllPendingSends(destination);
 
         assertTrue("Completion never got expected ISE", done.await(10, TimeUnit.SECONDS));
 
@@ -729,8 +718,6 @@ public class JmsMessageProducerTest extends JmsConnectionTestSupport {
     public void testCompletionListenerOnExceptionCallsProducerCloseThrowsISE() throws Exception {
         final int MESSAGE_COUNT = 1;
 
-        final MockRemotePeer remotePoor = MockRemotePeer.INSTANCE;
-
         JmsConnectionFactory factory = new JmsConnectionFactory(
             "mock://localhost?mock.delayCompletionCalls=true");
 
@@ -763,12 +750,12 @@ public class JmsMessageProducerTest extends JmsConnectionTestSupport {
         assertTrue("Not all sends made it to the remote", Wait.waitFor(new Wait.Condition() {
 
             @Override
-            public boolean isSatisified() throws Exception {
-                return remotePoor.getPendingCompletions(destination).size() == MESSAGE_COUNT;
+            public boolean isSatisfied() throws Exception {
+                return remotePeer.getPendingCompletions(destination).size() == MESSAGE_COUNT;
             }
         }));
 
-        remotePoor.failAllPendingSends(destination, new JMSException("Could not send message"));
+        remotePeer.failAllPendingSends(destination, new ProviderException("Could not send message"));
 
         assertTrue("Completion never got expected ISE", done.await(10, TimeUnit.SECONDS));
 
