@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -18,9 +18,6 @@ package org.apache.qpid.jms.selector;
 
 import java.util.HashMap;
 
-import junit.framework.TestCase;
-
-import org.apache.qpid.jms.selector.SelectorParser;
 import org.apache.qpid.jms.selector.filter.BooleanExpression;
 import org.apache.qpid.jms.selector.filter.ComparisonExpression;
 import org.apache.qpid.jms.selector.filter.Expression;
@@ -31,6 +28,8 @@ import org.apache.qpid.jms.selector.filter.PropertyExpression;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import junit.framework.TestCase;
+
 public class SelectorParserTest extends TestCase {
     private static final Logger LOG = LoggerFactory.getLogger(SelectorParserTest.class);
 
@@ -235,6 +234,8 @@ public class SelectorParserTest extends TestCase {
 
     /**
      * Test cases from Mats Henricson
+     *
+     * @throws Exception if an error occurs during the test.
      */
     public void testMatsHenricsonUseCases() throws Exception {
         MockMessage message = createMessage();
@@ -338,6 +339,8 @@ public class SelectorParserTest extends TestCase {
         assertInvalidSelector(message, "3+5");
         assertInvalidSelector(message, "True AND 3+5");
         assertInvalidSelector(message, "=TEST 'test'");
+        assertInvalidSelector(message, "prop1 = prop2 foo AND string = 'Test'");
+        assertInvalidSelector(message, "a = 1 AMD  b = 2");
     }
 
     public void testHyphenatedProperty() throws Exception {
