@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -20,7 +20,6 @@ import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
 
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.TimeUnit;
@@ -28,10 +27,6 @@ import java.util.concurrent.atomic.AtomicInteger;
 
 import javax.jms.Connection;
 import javax.jms.DeliveryMode;
-import javax.jms.ExceptionListener;
-import javax.jms.InvalidSelectorException;
-import javax.jms.JMSException;
-import javax.jms.JMSSecurityException;
 import javax.jms.Message;
 import javax.jms.MessageConsumer;
 import javax.jms.MessageListener;
@@ -97,7 +92,7 @@ public class JmsMessageConsumerTest extends AmqpTestSupport {
         assertTrue("Queued message not consumed.", Wait.waitFor(new Wait.Condition() {
 
             @Override
-            public boolean isSatisified() throws Exception {
+            public boolean isSatisfied() throws Exception {
                 return proxy.getQueueSize() == 0;
             }
         }));
@@ -123,7 +118,7 @@ public class JmsMessageConsumerTest extends AmqpTestSupport {
         assertTrue("Published message not consumed.", Wait.waitFor(new Wait.Condition() {
 
             @Override
-            public boolean isSatisified() throws Exception {
+            public boolean isSatisfied() throws Exception {
                 return proxy.getQueueSize() == 0;
             }
         }));
@@ -157,7 +152,7 @@ public class JmsMessageConsumerTest extends AmqpTestSupport {
         assertTrue("Listener not notified of correct number of messages.", Wait.waitFor(new Wait.Condition() {
 
             @Override
-            public boolean isSatisified() throws Exception {
+            public boolean isSatisfied() throws Exception {
                 return available.get() == MSG_COUNT;
             }
         }));
@@ -170,7 +165,7 @@ public class JmsMessageConsumerTest extends AmqpTestSupport {
         assertTrue("Queued message not consumed.", Wait.waitFor(new Wait.Condition() {
 
             @Override
-            public boolean isSatisified() throws Exception {
+            public boolean isSatisfied() throws Exception {
                 return proxy.getQueueSize() == 0;
             }
         }));
@@ -183,9 +178,9 @@ public class JmsMessageConsumerTest extends AmqpTestSupport {
      * want to test the short poll and retry case here since that's not what we are
      * testing.
      *
-     * @throws Exception
+     * @throws Exception on error found during test run.
      */
-    @Test(timeout=60000)
+    @Test(timeout = 60000)
     public void testConsumerReceiveBeforeMessageDispatched() throws Exception {
         final Connection connection = createAmqpConnection();
         this.connection = connection;
@@ -212,7 +207,7 @@ public class JmsMessageConsumerTest extends AmqpTestSupport {
         assertNotNull(msg);
     }
 
-    @Test(timeout=60000)
+    @Test(timeout = 60000)
     public void testAsynchronousMessageConsumption() throws Exception {
         final int msgCount = 4;
         final Connection connection = createAmqpConnection();
@@ -237,94 +232,10 @@ public class JmsMessageConsumerTest extends AmqpTestSupport {
         });
 
         sendToAmqQueue(msgCount);
-        assertTrue(done.await(1000, TimeUnit.MILLISECONDS));
-        TimeUnit.SECONDS.sleep(1);
+        assertTrue(done.await(5000, TimeUnit.MILLISECONDS));
         assertEquals(msgCount, counter.get());
     }
 
-    @Test(timeout=60000)
-    public void testSyncReceiveFailsWhenListenerSet() throws Exception {
-        final int msgCount = 4;
-        final Connection connection = createAmqpConnection();
-        final AtomicInteger counter = new AtomicInteger(0);
-        final CountDownLatch done = new CountDownLatch(1);
-        this.connection = connection;
-
-        connection.start();
-        Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Queue destination = session.createQueue(name.getMethodName());
-        MessageConsumer consumer = session.createConsumer(destination);
-
-        consumer.setMessageListener(new MessageListener() {
-            @Override
-            public void onMessage(Message m) {
-                LOG.debug("Async consumer got Message: {}", m);
-                counter.incrementAndGet();
-                if (counter.get() == msgCount) {
-                    done.countDown();
-                }
-            }
-        });
-
-        try {
-            consumer.receive();
-            fail("Should have thrown an exception.");
-        } catch (JMSException ex) {
-        }
-
-        try {
-            consumer.receive(1000);
-            fail("Should have thrown an exception.");
-        } catch (JMSException ex) {
-        }
-
-        try {
-            consumer.receiveNoWait();
-            fail("Should have thrown an exception.");
-        } catch (JMSException ex) {
-        }
-    }
-
-    @Test(timeout=60000)
-    public void testSetMessageListenerAfterStartAndSend() throws Exception {
-        final int msgCount = 4;
-        final Connection connection = createAmqpConnection();
-        final AtomicInteger counter = new AtomicInteger(0);
-        final CountDownLatch done = new CountDownLatch(1);
-        this.connection = connection;
-
-        connection.start();
-        Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Queue destination = session.createQueue(name.getMethodName());
-        MessageConsumer consumer = session.createConsumer(destination);
-        sendToAmqQueue(msgCount);
-
-        consumer.setMessageListener(new MessageListener() {
-            @Override
-            public void onMessage(Message m) {
-                LOG.debug("Async consumer got Message: {}", m);
-                counter.incrementAndGet();
-                if (counter.get() == msgCount) {
-                    done.countDown();
-                }
-            }
-        });
-
-        assertTrue(done.await(1000, TimeUnit.MILLISECONDS));
-        TimeUnit.SECONDS.sleep(1);
-        assertEquals(msgCount, counter.get());
-    }
-
-    @Test(timeout=60000)
-    public void testNoReceivedMessagesWhenConnectionNotStarted() throws Exception {
-        connection = createAmqpConnection();
-        Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Queue destination = session.createQueue(name.getMethodName());
-        MessageConsumer consumer = session.createConsumer(destination);
-        sendToAmqQueue(3);
-        assertNull(consumer.receive(2000));
-    }
-
     @Test(timeout = 60000)
     public void testMessagesAreAckedAMQProducer() throws Exception {
         int messagesSent = 3;
@@ -479,7 +390,7 @@ public class JmsMessageConsumerTest extends AmqpTestSupport {
         assertTrue("Queue did not get all expected messages", Wait.waitFor(new Wait.Condition() {
 
             @Override
-            public boolean isSatisified() throws Exception {
+            public boolean isSatisfied() throws Exception {
                 return proxy.getQueueSize() == 2;
             }
         }));
@@ -491,157 +402,4 @@ public class JmsMessageConsumerTest extends AmqpTestSupport {
         assertEquals("Unexpected JMSType value", type, msg.getJMSType());
         assertEquals("Unexpected message content", "text + type", ((TextMessage) msg).getText());
     }
-
-    @Test(timeout=90000, expected=JMSSecurityException.class)
-    public void testConsumerNotAuthorized() throws Exception{
-        connection = createAmqpConnection("guest", "password");
-        connection.start();
-        Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Queue queue = session.createQueue("USERS." + name.getMethodName());
-        session.createConsumer(queue);
-    }
-
-    @Test(timeout=90000, expected=InvalidSelectorException.class)
-    public void testInvalidSelector() throws Exception{
-        connection = createAmqpConnection();
-        connection.start();
-        Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Queue queue = session.createQueue(name.getMethodName());
-        session.createConsumer(queue, "3+5");
-    }
-
-    @Test(timeout=30000)
-    public void testConsumerReceiveNoWaitThrowsWhenBrokerStops() throws Exception {
-        final CountDownLatch consumerReady = new CountDownLatch(1);
-        final CountDownLatch connectionFailed = new CountDownLatch(1);
-
-        connection = createAmqpConnection();
-        connection.setExceptionListener(new ExceptionListener() {
-
-            @Override
-            public void onException(JMSException exception) {
-                LOG.info("Connection to Broker stopped");
-                connectionFailed.countDown();
-            }
-        });
-
-        Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Queue queue = session.createQueue(getDestinationName());
-        connection.start();
-
-        final MessageConsumer consumer=session.createConsumer(queue);
-        Testable test = new Testable() {
-
-            @Override
-            public synchronized void run() {
-                try {
-                    consumerReady.countDown();
-                    assertTrue("Broker connection needs to fail.", connectionFailed.await(20, TimeUnit.SECONDS));
-
-                    // Might not propagate state right away, so check a few times.
-                    for (int i = 0; i < 250; i++) {
-                        consumer.receiveNoWait();
-                        TimeUnit.MILLISECONDS.sleep(3);
-                    }
-
-                    failure = "Should have thrown an IllegalStateException";
-                } catch (Exception ex) {
-                    LOG.info("Caught exception on receiveNoWait: {}", ex);
-                }
-            }
-        };
-
-        new Thread(test).start();
-        assertTrue(consumerReady.await(20, TimeUnit.SECONDS));
-
-        stopPrimaryBroker();
-
-        assertTrue("Consumer did not fail as expected", test.passed());
-    }
-
-    @Test(timeout=30000)
-    public void testConsumerReceiveTimedReturnsIfConnectionLost() throws Exception {
-        final CountDownLatch consumerReady = new CountDownLatch(1);
-
-        connection = createAmqpConnection();
-        Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Queue queue = session.createQueue(getDestinationName());
-        connection.start();
-
-        final MessageConsumer consumer=session.createConsumer(queue);
-
-        Testable test = new Testable() {
-            @Override
-            public synchronized void run() {
-                try {
-                    consumer.receive(1);
-                    new Thread(new Runnable() {
-
-                        @Override
-                        public void run() {
-                            try {
-                                TimeUnit.MILLISECONDS.sleep(2);
-                            } catch (InterruptedException e) {
-                            }
-                            consumerReady.countDown();
-                        }
-                    }).start();
-                    consumer.receive(TimeUnit.SECONDS.toMillis(30));
-                } catch (Exception ex) {
-                    LOG.info("Caught exception on receive(): {}", ex);
-                    failure = "Should not have thrown: " + ex.getMessage();
-                }
-            }
-        };
-
-        new Thread(test).start();
-        assertTrue(consumerReady.await(20, TimeUnit.SECONDS));
-
-        stopPrimaryBroker();
-
-        assertTrue(test.passed());
-    }
-
-    @Test(timeout=30000)
-    public void testConsumerReceiveReturnsIfConnectionLost() throws Exception {
-        final CountDownLatch consumerReady = new CountDownLatch(1);
-
-        connection = createAmqpConnection();
-        Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Queue queue = session.createQueue(getDestinationName());
-        connection.start();
-
-        final MessageConsumer consumer=session.createConsumer(queue);
-
-        Testable test = new Testable() {
-            @Override
-            public synchronized void run() {
-                try {
-                    consumer.receive(1);
-                    new Thread(new Runnable() {
-
-                        @Override
-                        public void run() {
-                            try {
-                                TimeUnit.MILLISECONDS.sleep(2);
-                            } catch (InterruptedException e) {
-                            }
-                            consumerReady.countDown();
-                        }
-                    }).start();
-                    consumer.receive();
-                } catch (Exception ex) {
-                    LOG.info("Caught exception on receive(): {}", ex);
-                    failure = "Should not have thrown: " + ex.getMessage();
-                }
-            }
-        };
-
-        new Thread(test).start();
-        assertTrue(consumerReady.await(20, TimeUnit.SECONDS));
-
-        stopPrimaryBroker();
-
-        assertTrue(test.passed());
-    }
 }
